dilbert.py
===========

.. image:: https://img.shields.io/github/license/pysics/dilbert.py
    :target: https://github.com/Pysics/dilbert.py/blob/main/LICENSE.md
    :alt: license
.. image:: https://img.shields.io/tokei/lines/github/pysics/dilbert.py
    :target: https://github.com/Pysics/dilbert.py/graphs/contributors
    :alt: lines of code
.. image:: https://img.shields.io/pypi/v/dilbert.py
    :target: https://pypi.python.org/pypi/dilbert.py
    :alt: PyPI version info
.. image:: https://img.shields.io/pypi/pyversions/dilbert.py
    :alt: Python version info


Requirements
------------

This module requires the following modules:

* `beautifulsoup4 <https://pypi.python.org/pypi/beautifulsoup4>`_
* `requests <https://pypi.python.org/pypi/requests>`_


Installation
------------

**Python 3.8 or higher is required.**

To install the stable version, do the following:

.. code-block:: sh

    # Unix / macOS
    python3 -m pip install "dilbert.py"

    # Windows
    py -m pip install "dilbert.py"


To install the development version, do the following:

.. code-block:: sh

    $ git clone https://github.com/Pysics/dilbert.py


Links
-----

- `dilbert <https://dilbert.com/>`_
- `Documentation <https://dilbert.readthedocs.io/>`_